//
//  GMImagePickerHelper.swift
//
//  Created by Mayank Patil on 17/05/22.
//  Copyright © 2022 The Chromium Authors. All rights reserved.
//

import Foundation
import UIKit
import GMImagePickerWithCloudMediaDownloading
import Flutter
import AVFoundation
/**
 - GMImagePicker Helper class
 Helps in picking image for the older versions of iOS
 */
class GMImagePickerHelper : NSObject, GMImagePickerControllerDelegate {
    var limit : Int = 0 // asset selection limit
    var assetCount : Int = 0 // asset count
    var resultProtocol: ImagePickerResult?
    public init(resultProtocol: ImagePickerResult) {
        super.init()
        self.resultProtocol = resultProtocol
    }
    
    /** Finish selecting photos from Photos App */
    public func assetsPickerController(_ picker: GMImagePickerController!, didFinishPickingAssets assets: [Any]!) {
        // background thread
        DispatchQueue.global(qos: .background).async {
            
            if assets is [PHAsset] {
                
                let paths = self.getAbsoluteUrl(assets: assets as! [PHAsset])
                DispatchQueue.main.async {
                    // main thread
                    let resultData : [String:Any] = ["uris":paths]
                    self.resultProtocol?.didFinishPickingImage(jsonString: resultData.jsonString!)
                    picker.dismiss(animated: true, completion: nil)
                }
            }
        }
    }
    
    /** Photos app cancelled */
    func assetsPickerControllerDidCancel(_ picker: GMImagePickerController!) {
        self.resultProtocol?.didCancelPickingImage()
        picker.dismiss(animated: true, completion: nil)
    }
    
    /** Decides selection for an asset*/
    func assetsPickerController(_ picker: GMImagePickerController!, shouldSelect asset: PHAsset!) -> Bool {
        print("Invoked Validation Method: \(picker.selectedAssets.count)")
        var allowSelection = true
        if self.limit > 0 && self.limit == self.assetCount {
            allowSelection = false
        } else {
            self.assetCount = self.assetCount + 1
        }
        return allowSelection
    }
    
    /** Decides deselection for an asset */
    func assetsPickerController(_ picker: GMImagePickerController!, shouldDeselect asset: PHAsset!) -> Bool {
        if self.assetCount > 0 {
            self.assetCount = self.assetCount-1
        }
        return true
    }
    
    /** Opens the pickerViewController to show Photos App View */
    func pickImagesFromPhotosApp(limit: Int) {
        
        let picker = GMImagePickerController()
        picker.delegate = self
        picker.title = "Select"
        self.assetCount = 0
        self.limit = limit
        picker.customCancelButtonTitle = "Cancel"
        picker.customDoneButtonTitle = "Done"
        picker.allowsMultipleSelection = true
        picker.displaySelectionInfoToolbar = true
        picker.displayAlbumsNumberOfAssets = true
        picker.modalPresentationStyle = .fullScreen
        
        // below line is added to avoid/fix a library specific crash
        picker.navigationController?.toolbar?.addSubview(UIView())
        
        if let viewController = (UIApplication.shared.delegate as? FlutterAppDelegate)?.window?.rootViewController {
            viewController.present(picker, animated: true, completion: nil)
        }
    }
    
    /** Get the absolute url from the image path */
    func getAbsoluteUrl(assets: [PHAsset]) -> [String] {
        var paths: [String] = []
        
        let group = DispatchGroup()
        var path = ""
        for asset in assets {
            group.enter()
            asset.requestContentEditingInput(with: PHContentEditingInputRequestOptions(), completionHandler: {(data,args) in
                path = data?.fullSizeImageURL?.path ?? ""
                group.leave()
            })
            group.wait()
            paths.append(path)
        }
        return paths
    }
}

/** Extension added for json conversion*/
extension Dictionary {
    
    var jsonString: String? {
        if let json = try? JSONSerialization.data(withJSONObject: self) {
            let convertedString = String(data: json, encoding: String.Encoding.utf8)
            return convertedString
        }
        return nil
    }
}
