import Flutter
import UIKit
import  GMImagePickerWithCloudMediaDownloading

//  protocol for communicating with the GMImagePickerHelper class
protocol ImagePickerResult {
func didFinishPickingImage(jsonString: String)
func didCancelPickingImage()
}

// Method channel implementation for iOS
public class SwiftScanbotImagePickerFlutterPlugin: NSObject, FlutterPlugin, ImagePickerResult {
    
    var result: FlutterResult?
    var imagePickerHelper: GMImagePickerHelper?

    // initialiser
    override public init() {
        super.init()
        self.imagePickerHelper = GMImagePickerHelper(resultProtocol: self)
    }

    // Registration of method channel handler
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "scanbot_image_picker_flutter", binaryMessenger: registrar.messenger())
        let instance = SwiftScanbotImagePickerFlutterPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    // Method channel hadnler callback definition
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        DispatchQueue.main.async {
            switch call.method {
            case "pickImagesFromPhotosApp":
                self.result = result
                if let args = call.arguments as? Dictionary<String,Any>, let limit = args["limit"] as? Int {
                    self.imagePickerHelper?.pickImagesFromPhotosApp(limit: limit)
                }
            case "versionLessThanIOSFourteen":
                result(self.versionLessThanIOSFourteen())
                
            default:
                result("iOS " + UIDevice.current.systemVersion)
            }
        }
    }
    
    /// This methods are called from the GMImagePickerHelper class when the image picking is completed by user.
    func didFinishPickingImage(jsonString: String) {
        self.result?(jsonString)
    }

    /// This method is called from the GMImagePickerHelper class when user cancels picking images.
    func didCancelPickingImage() {
        self.result?([])
    }
    
    /**
     Is version less than iOS 14
     */
    func versionLessThanIOSFourteen() -> String {
        if #available(iOS 14, *) {
            return "false"
        } else {
            return "true"
        }
    }
}
